<#
.DESCRIPTION
Install all available Windows Updates.

.EXAMPLE


.NOTES
Author: Thomas Kurth/Netree
Date:   25.05.2013

History
    001: First Version

#>

$UpdateSession = New-Object -Com Microsoft.Update.Session
$UpdateSearcher = $UpdateSession.CreateUpdateSearcher()
 
Write-Verbose("Searching for applicable updates...")
 
$SearchResult = $UpdateSearcher.Search("IsInstalled=0 and Type='Software'")
 
Write-Verbose("List of applicable items on the machine:")
For ($X = 0; $X -lt $SearchResult.Updates.Count; $X++){
    $Update = $SearchResult.Updates.Item($X)
    Write-Verbose( ($X + 1).ToString() + "&gt; " + $Update.Title)
}
 
If ($SearchResult.Updates.Count -eq 0) {
    Write-Verbose("There are no applicable updates.")
} else {
 
    $UpdatesToDownload = New-Object -Com Microsoft.Update.UpdateColl
 
    For ($X = 0; $X -lt $SearchResult.Updates.Count; $X++){
        $Update = $SearchResult.Updates.Item($X)
        $Null = $UpdatesToDownload.Add($Update)
    }
 
    Write-Verbose("Downloading Updates...")
 
    $Downloader = $UpdateSession.CreateUpdateDownloader()
    $Downloader.Updates = $UpdatesToDownload
    $DownloadResult = $Downloader.Download()
    Write-Verbose $DownloadResult
 
    $UpdatesToInstall = New-Object -Com Microsoft.Update.UpdateColl
 
    For ($X = 0; $X -lt $SearchResult.Updates.Count; $X++){
        $Update = $SearchResult.Updates.Item($X)
        If ($Update.IsDownloaded) {
            $Null = $UpdatesToInstall.Add($Update)        
        }
    }
 
    Write-Verbose("Installing Updates...")
 
    $Installer = $UpdateSession.CreateUpdateInstaller()
    $Installer.Updates = $UpdatesToInstall
 
    $InstallationResult = $Installer.Install()
 
    Write-Verbose("List of Updates Installed with Results:")
 
    For ($X = 0; $X -lt $UpdatesToInstall.Count; $X++){
        Write-Verbose($UpdatesToInstall.Item($X).Title + ": " + $InstallationResult.GetUpdateResult($X).ResultCode)
    }
 
    Write-Verbose("Installation Result: " + $InstallationResult.ResultCode)
    Write-Verbose("    Reboot Required: " +   $InstallationResult.RebootRequired)
 
    If ($InstallationResult.RebootRequire -eq $True){
        Write-Warning "Reboot Required"
    }
}
